@@ -80,7 +80,7 @@ has 'stat_helper'          => (
         return sub {
             my ($name, $handle) = @_;
             return if(not $self->activated or not $name =~ $self->re_pattern);
-            my $array = AI::MXNet::NDArray->new(handle => $handle, writable => 0);
+            my $array = AI::MXNet::NDArray->_ndarray_cls($handle, 0);
             push @{ $self->queue }, [$self->step, $name, $self->stat_func->($array)];
         }
     },
@@ -145,14 +145,14 @@ method toc()
     }
     for my $exe (@{ $self->exes })
     {
-        zip(sub {
-            my ($name, $array) = @_;
+        for(zip($exe->_symbol->list_arguments, $exe->arg_arrays)) {
+            my ($name, $array) = @$_;
             push @{ $self->queue }, [$self->step, $name, $self->stat_func->($array)];
-        }, $exe->_symbol->list_arguments, $exe->arg_arrays);
-        zip(sub {
-            my ($name, $array) = @_;
+        }
+        for(zip($exe->_symbol->list_auxiliary_states, $exe->aux_arrays)) {
+            my ($name, $array) = @$_;
             push @{ $self->queue }, [$self->step, $name, $self->stat_func->($array)];
-        }, $exe->_symbol->list_auxiliary_states, $exe->aux_arrays);
+        }
     }
     $self->activated(0);
     my @res;
